==> civic_accessibility_toolbar-1.0.0.tar.gz: civic_accessibility_toolbar/src/Plugin/Block/AccessibilityToolbarBlock.php <==
<?php

namespace Drupal\civic_accessibility_toolbar\Plugin\Block;

/**
 * @file
 * Contains \Drupal\civic_accessibility_toolbar\Plugin\Block\accessibilityToolbarBlock.
 */

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides an accessibility_toolbar block.
 *
 * @Block(
 *   id = "accessibility_toolbar_block",
 *   admin_label = @Translation("Accessibility Toolbar"),
 * )
 */
class AccessibilityToolbarBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function access(AccountInterface $account, $return_as_object = FALSE) {
    $access = $this->blockAccess($account);
    return $return_as_object ? $access : $access->isAllowed('access content');
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {

    $form['text_resize'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show text resize toolbar'),
      '#description' => $this->t('Check to show the text resize toolbar'),
      '#default_value' => isset($this->configuration['text_resize']) ? $this->configuration['text_resize'] : TRUE,
    ];
    $form['text_resize_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Text resize label'),
      '#description' => $this->t('Leave empty for no labler'),
      '#default_value' => isset($this->configuration['text_resize_label']) ? $this->configuration['text_resize_label'] : 'Text',
    ];
    $form['colour_contrast'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show colour contrast toolbar'),
      '#description' => $this->t('Check to show the colour contrast toolbar'),
      '#default_value' => isset($this->configuration['colour_contrast']) ? $this->configuration['colour_contrast'] : TRUE,
    ];
    $form['colour_contrast_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Colour contrast label'),
      '#description' => $this->t('Leave empty for no labler'),
      '#default_value' => isset($this->configuration['colour_contrast_label']) ? $this->configuration['colour_contrast_label'] : 'Colour',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['text_resize'] = $values['text_resize'];
    $this->configuration['colour_contrast'] = $values['colour_contrast'];
    $this->configuration['text_resize_label'] = $values['text_resize_label'];
    $this->configuration['colour_contrast_label'] = $values['colour_contrast_label'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'block__accessibility_toolbar',
      '#text_resize' => $this->configuration['text_resize'],
      '#colour_contrast' => $this->configuration['colour_contrast'],
      '#text_resize_label' => $this->configuration['text_resize_label'],
      '#colour_contrast_label' => $this->configuration['colour_contrast_label'],
      '#attached' => [
        'library' => ['civic_accessibility_toolbar/civic_accessibility_toolbar.accessibility_toolbar'],
      ],
    ];
  }

}

==> civic_accessibility_toolbar-1.0.1.tar.gz: civic_accessibility_toolbar/src/Plugin/Block/AccessibilityToolbarBlock.php <==
<?php

namespace Drupal\civic_accessibility_toolbar\Plugin\Block;

/**
 * @file
 * Contains \Drupal\civic_accessibility_toolbar\Plugin\Block\accessibilityToolbarBlock.
 */

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides an accessibility_toolbar block.
 *
 * @Block(
 *   id = "accessibility_toolbar_block",
 *   admin_label = @Translation("Accessibility Toolbar"),
 * )
 */
class AccessibilityToolbarBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function access(AccountInterface $account, $return_as_object = FALSE) {
    $access = $this->blockAccess($account);
    return $return_as_object ? $access : $access->isAllowed('access content');
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {

    $form['text_resize'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show text resize toolbar'),
      '#description' => $this->t('Check to show the text resize toolbar'),
      '#default_value' => isset($this->configuration['text_resize']) ? $this->configuration['text_resize'] : TRUE,
    ];
    $form['text_resize_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Text resize label'),
      '#description' => $this->t('Leave empty for no label'),
      '#default_value' => isset($this->configuration['text_resize_label']) ? $this->configuration['text_resize_label'] : 'Text',
    ];
    $form['color_contrast'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show color contrast toolbar'),
      '#description' => $this->t('Check to show the color contrast toolbar'),
      '#default_value' => isset($this->configuration['color_contrast']) ? $this->configuration['color_contrast'] : TRUE,
    ];
    $form['color_contrast_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Color contrast label'),
      '#description' => $this->t('Leave empty for no label'),
      '#default_value' => isset($this->configuration['color_contrast_label']) ? $this->configuration['color_contrast_label'] : 'Color',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['text_resize'] = $values['text_resize'];
    $this->configuration['color_contrast'] = $values['color_contrast'];
    $this->configuration['text_resize_label'] = $values['text_resize_label'];
    $this->configuration['color_contrast_label'] = $values['color_contrast_label'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'block__accessibility_toolbar',
      '#text_resize' => $this->configuration['text_resize'],
      '#color_contrast' => $this->configuration['color_contrast'],
      '#text_resize_label' => $this->configuration['text_resize_label'],
      '#color_contrast_label' => $this->configuration['color_contrast_label'],
      '#attached' => [
        'library' => ['civic_accessibility_toolbar/civic_accessibility_toolbar.accessibility_toolbar'],
      ],
    ];
  }

}
